'use strict';

var async = require('async'),
    SensorTag = require('sensortag'),
    config = require('./config');

SensorTag.discover(function(sensorTag) {
  console.log('discovered: ' + sensorTag);
  sensorTag.on('disconnect', function() {
    console.log('Tag Disconnected');
    process.exit(0);
  });

  process.on('SIGINT', function() {
    sensorTag.disconnect();
  });

  async.waterfall([
    function(callback) {
      console.log('connectAndSetUp');
      sensorTag.connectAndSetUp(callback);
    },
    function(callback) {
      console.log('enableIrTemperature');
      sensorTag.enableIrTemperature(callback);
    },
    function(callback) {
      console.log('enableBarometricPressure');
      sensorTag.enableBarometricPressure(callback);
    },
    function(callback) {
      sensorTag.enableBarometricPressure(callback);
    },
    function(callback) {
      setTimeout(callback, 2000);
    },
    function(callback) {
      async.forever(function(callback) {
        async.series([
          function(callback) {
            sensorTag.readIrTemperature(
              function(error, objTemp, ambTemp) {
              var payload = {
                objTemp: objTemp.toFixed(1),
                ambTemp: ambTemp.toFixed(1)
              };
              callback(null, payload);
            });
          },
          function(callback) {
            sensorTag.readBarometricPressure(
              function(err, pressure){
                var payload = {
                  pressure: pressure
                };
                callback(null, payload);
              });
          }
        ],
        function(err, res) {
          console.log('物体温度: '+ res[0].objTemp+' ℃');
          console.log('周囲温度: '+ res[0].ambTemp+' ℃');
          console.log('気圧    : '+ res[1].pressure+' mBa');
          setTimeout(callback, config.waitTime);
        });
      },
      function(err) {
        if (err) throw err;
      });
    }
  ], function (err) {
    if (err) throw err;
  });
});

